<?php
/**
* Counter options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Counter enable section
$wp_customize->add_section( 'graduate_pro_counter_content_section', array(
	'title'             => esc_html__( 'Counter Section','graduate-pro' ),
	'description'       => esc_html__( 'Counter section options.', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add Counter enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_content_enable]', array(
	'default'           => $options['counter_content_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_content_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_counter_content_section',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add Counter type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_content_type]', array(
	'default'           => $options['counter_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_content_type]', array(
	'label'           => esc_html__( 'Counter Heading Content Type', 'graduate-pro' ),
	'section'         => 'graduate_pro_counter_content_section',
	'type'            => 'select',
	'active_callback' => 'graduate_pro_is_counter_active',
	'choices'         => graduate_pro_counter_content_type()
) );

// Page Content Type
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_content_page]', array(
	'sanitize_callback' => 'graduate_pro_sanitize_page'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'graduate-pro' ),
	'section'        	=> 'graduate_pro_counter_content_section',
	'active_callback' 	=> 'graduate_pro_is_counter_heading_page',
	'type'				=> 'dropdown-pages'
) );

// Post Content Type
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_content_post]', array(
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback' => 'graduate_pro_validate_post_id'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_content_post]', array(
	'label'           	=> esc_html__( 'Input Post ID', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_counter_content_section',
	'active_callback' 	=> 'graduate_pro_is_counter_heading_post',
	'type'				=> 'number',
	'input_attrs'     	=> array(
		'min'	=> 1,
		'style' => 'width:100px'
		)
) );

// Featurd Posts image setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_background]', array(
	'default'           => $options['counter_background'],
	'sanitize_callback' => 'graduate_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'graduate_pro_theme_options[counter_background]',
		array(
		'label'       		=> esc_html__( 'Featured Image', 'graduate-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'graduate-pro' ), 748, 900 ),
		'section'     		=> 'graduate_pro_counter_content_section',
		'active_callback'	=> 'graduate_pro_is_counter_heading_custom',
) ) );

// Add Counter heading title.
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_heading_title]', array(
	'default'           => $options['counter_heading_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_heading_title]', array(
	'label'           	=> esc_html__( 'Title', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_counter_content_section',
	'type'            	=> 'text',
	'active_callback' 	=> 'graduate_pro_is_counter_heading_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'graduate_pro_theme_options[counter_heading_title]', array(
		'selector'            => '#counter-section .entry-header h2.entry-title',
		'settings'            => 'graduate_pro_theme_options[counter_heading_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'graduate_pro_partial_counter_title',
    ) );
}

// Add Counter heading description.
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_heading_description]', array(
	'default'           => $options['counter_heading_description'],
	'sanitize_callback' => 'esc_textarea',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_heading_description]', array(
	'label'           	=> esc_html__( 'Description', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_counter_content_section',
	'type'            	=> 'textarea',
	'active_callback' 	=> 'graduate_pro_is_counter_heading_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'graduate_pro_theme_options[counter_heading_description]', array(
		'selector'            => '#counter-section .entry-content p',
		'settings'            => 'graduate_pro_theme_options[counter_heading_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'graduate_pro_partial_counter_description',
    ) );
}

// Add Counter heading btn label.
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_btn_label]', array(
	'default'           => $options['counter_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_counter_content_section',
	'type'            	=> 'text',
	'active_callback' 	=> 'graduate_pro_is_counter_active',
) );

// Add Counter heading btn url.
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_btn_url]', array(
	'default'           => $options['counter_btn_url'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_counter_content_section',
	'type'            	=> 'url',
	'active_callback' 	=> 'graduate_pro_is_counter_heading_custom',
) );

// Add Counter heading btn label.
$wp_customize->add_setting( 'graduate_pro_theme_options[counter_box_enable]', array(
	'default'           => $options['counter_box_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'graduate_pro_theme_options[counter_box_enable]', array(
	'label'           	=> esc_html__( 'Display Counter Box', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_counter_content_section',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_counter_active',
) );

for ( $i = 1; $i <= 4; $i++ ) {
	// counter content type hr setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[counter_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new graduate_Pro_Customize_Horizontal_Line( $wp_customize, 'graduate_pro_theme_options[counter_hr_' . $i . ']',
		array(
			'section'         => 'graduate_pro_counter_content_section',
			'active_callback' => 'graduate_pro_is_counter_box_enabled',
			'type'			  => 'hr'
	) ) );

	// Add Counter heading btn label.
	$wp_customize->add_setting( 'graduate_pro_theme_options[counter_box_count_' . $i . ']', array(
		'default'           => $options['counter_box_count_' . $i],
		'validate_callback' => 'graduate_pro_validate_counter_value',
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[counter_box_count_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Value %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_counter_content_section',
		'type'            	=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'style'	=> 'width:100px',	
			),
		'active_callback' 	=> 'graduate_pro_is_counter_box_enabled',
	) );

	// Add Counter heading btn label.
	$wp_customize->add_setting( 'graduate_pro_theme_options[counter_label_' . $i . ']', array(
		'default'           => $options['counter_label_' . $i],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[counter_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Label %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_counter_content_section',
		'type'            	=> 'text',
		'active_callback' 	=> 'graduate_pro_is_counter_box_enabled',
	) );
}