<?php
/**
* News & Events options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add News & Events enable section
$wp_customize->add_section( 'graduate_pro_news_events', array(
	'title'             => esc_html__( 'News & Events','graduate-pro' ),
	'description'		=> sprintf( '<b>%1$s:</b> %2$s', esc_html__( 'Info', 'graduate-pro' ), esc_html__( ' New Custom Category ( Taxonomy ) will be added automatically to Content Type as its registered. To see list of custom categories ( Terms ), select custom category in content type and save. Then refresh the page to see the list of custom categories.', 'graduate-pro' ) ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add News & Events enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[news_events_enable]', array(
	'default'           => $options['news_events_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[news_events_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_news_events',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add News & Events title.
$wp_customize->add_setting( 'graduate_pro_theme_options[news_events_title]', array(
	'default'           => $options['news_events_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[news_events_title]', array(
	'label'           	=> esc_html__( 'Title', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_news_events',
	'type'            	=> 'text',
	'active_callback' 	=> 'graduate_pro_is_news_events_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'graduate_pro_theme_options[news_events_title]', array(
		'selector'            => '#news-section .entry-header h2.entry-title',
		'settings'            => 'graduate_pro_theme_options[news_events_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'graduate_pro_partial_news_events_title',
    ) );
}

// Add News & Events description.
$wp_customize->add_setting( 'graduate_pro_theme_options[news_events_description]', array(
	'default'           => $options['news_events_description'],
	'sanitize_callback' => 'esc_textarea',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[news_events_description]', array(
	'label'           	=> esc_html__( 'Description', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_news_events',
	'type'            	=> 'textarea',
	'active_callback' 	=> 'graduate_pro_is_news_events_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'graduate_pro_theme_options[news_events_description]', array(
		'selector'            => '#news-section .entry-content p',
		'settings'            => 'graduate_pro_theme_options[news_events_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'graduate_pro_partial_news_events_description',
    ) );
}

// Add News & Events show title and description.
$wp_customize->add_setting( 'graduate_pro_theme_options[news_events_display_title]', array(
	'default'           => $options['news_events_display_title'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[news_events_display_title]', array(
	'label'           	=> esc_html__( 'Display Title & Description', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_news_events',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_news_events_active',
) );

// Add News & Events Column.
$wp_customize->add_setting( 'graduate_pro_theme_options[news_events_column]', array(
	'default'           => $options['news_events_column'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[news_events_column]', array(
	'label'           	=> esc_html__( 'Select Column Layout', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_news_events',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_news_events_active',
	'choices'         	=> graduate_pro_information_section_column()
) );

// Add News & Events type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[news_events_content_type]', array(
	'default'           => $options['news_events_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[news_events_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_news_events',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_news_events_active',
	'choices'         	=> graduate_pro_news_taxonomy_content_type()
) );

// Category Content Type
$wp_customize->add_setting(  'graduate_pro_theme_options[news_events_content_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new graduate_Pro_Dropdown_Category_Control ( $wp_customize,'graduate_pro_theme_options[news_events_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'graduate-pro' ),
	'section'           => 'graduate_pro_news_events',
	'type'              => 'dropdown-category',
	'active_callback'	=> 'graduate_pro_is_news_events_category_active'
) ) );

// Taxonomy Content Type
$wp_customize->add_setting(  'graduate_pro_theme_options[news_events_'. $options['news_events_content_type'] .']', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new graduate_Pro_Dropdown_Taxonomies_Control ( $wp_customize,'graduate_pro_theme_options[news_events_'. $options['news_events_content_type'] .']', array(
	'label'             => esc_html__( 'Select Term', 'graduate-pro' ),
	'section'           => 'graduate_pro_news_events',
	'taxonomy'          => $options['news_events_content_type'],
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'graduate_pro_is_news_events_taxonomy_active'
) ) );

// Add News & Events Count.
$wp_customize->add_setting( 'graduate_pro_theme_options[news_events_count]', array(
	'default'           => $options['news_events_count'],
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback'	=> 'graduate_pro_validate_trending_course_count'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[news_events_count]', array(
	'label'           	=> esc_html__( 'No of Posts', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_news_events',
	'type'            	=> 'number',
	'active_callback' 	=> 'graduate_pro_is_news_events_not_demo',
	'input_attrs'		=> array(
		'max'	=> 8,
		'min'	=> 2,
		'style'	=> 'width:100px'
		)
) );