<?php
/**
* Slider options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add slider enable section
$wp_customize->add_section( 'graduate_pro_slider_section', array(
	'title'             => esc_html__('Featured Slider','graduate-pro'),
	'description'       => esc_html__( 'Slider section options.', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add slider enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[slider_enable]', array(
	'default'           => $options['slider_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[slider_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_slider_section',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add slider effects setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[slider_content_effect]', array(
	'default'           => $options['slider_content_effect'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[slider_content_effect]', array(
	'label'           	=> esc_html__( 'Transition Effects', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_slider_active',
	'choices'         	=> graduate_pro_slider_effect(),
) );

// Add enable slider transition duration setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[slider_transition_duration]', array(
	'default'           => $options['slider_transition_duration'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[slider_transition_duration]', array(
	'label'           	=> esc_html__( 'Transition Duration', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_slider_active',
	'choices'         	=> graduate_pro_slider_transition_duration(),
) );

// Add enable arrow controls setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[enable_slider_controls]', array(
	'default'           => $options['enable_slider_controls'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[enable_slider_controls]', array(
	'label'           	=> esc_html__( 'Enable Arrow Controls', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_slider_active',
) );

// Add enable slider pager setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[enable_slider_pager]', array(
	'default'           => $options['enable_slider_pager'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[enable_slider_pager]', array(
	'label'           	=> esc_html__( 'Enable Pager Controls', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_slider_active',
) );

// Add enable slider dragable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[enable_slider_dragable]', array(
	'default'           => $options['enable_slider_dragable'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[enable_slider_dragable]', array(
	'label'           	=> esc_html__( 'Slider Draggable', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_slider_active',
) );

// Add enable slider pause on hover setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[slider_pause_on_hover]', array(
	'default'           => $options['slider_pause_on_hover'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[slider_pause_on_hover]', array(
	'label'           	=> esc_html__( 'Pause On Hover', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_slider_active',
) );

// Add enable slider auto play setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[slider_autoplay]', array(
	'default'           => $options['slider_autoplay'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[slider_autoplay]', array(
	'label'           	=> esc_html__( 'Auto Play', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'graduate_pro_is_slider_active',
) );

// Slider post hr setting and control
$wp_customize->add_setting( 'graduate_pro_theme_options[slider_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new graduate_Pro_Customize_Horizontal_Line( $wp_customize, 'graduate_pro_theme_options[slider_hr]',
	array(
		'section'         => 'graduate_pro_slider_section',
		'active_callback' => 'graduate_pro_is_slider_active',
		'type'			  => 'hr'
) ) );

// Add slider content type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[slider_content_type]', array(
	'default'           => $options['slider_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[slider_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'graduate-pro' ),
	'description'     	=> esc_html__( 'Recommended slider image size is 1200x500 px', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_slider_active',
	'choices'         	=> graduate_pro_common_content_type()
) );

// Add slider number setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[no_of_slider]', array(
	'default'           => $options['no_of_slider'],
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback' => 'graduate_pro_validate_no_of_slider',
) );

$wp_customize->add_control( 'graduate_pro_theme_options[no_of_slider]', array(
	'label'           	=> esc_html__( 'Number of slides', 'graduate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then referesh the page to see the change.', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_slider_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'graduate_pro_slider_demo_active',
	'input_attrs'     	=> array(
		'max' 	=> 5,
		'min' 	=> 1,
		'style' => 'width:100px'
	)
) );

/**
 * Page Content Type
 */
for ( $i = 1; $i <= $options['no_of_slider']; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[slider_content_page_'.$i.']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[slider_content_page_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'graduate-pro' ), $i ),
		'section'        	=> 'graduate_pro_slider_section',
		'active_callback' 	=> 'graduate_pro_is_slider_page_content_active',
		'type'				=> 'dropdown-pages'
	) );
}

/*
* Post Content Type
 */
for ( $i = 1; $i <= $options['no_of_slider']; $i++ ) {
	// Show post type setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[slider_content_post_'.$i.']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_number_range',
		'validate_callback' => 'graduate_pro_validate_post_id'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[slider_content_post_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Post ID %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_slider_section',
		'active_callback' 	=> 'graduate_pro_is_slider_post_content_active',
		'type'				=> 'number',
		'input_attrs'     	=> array(
			'min'	=> 1,
			'style' => 'width:100px'
			)
	) );
}

/*
* Category Content Type
*/
// Add  dropdown category setting and control.
$wp_customize->add_setting(  'graduate_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new graduate_Pro_Dropdown_Category_Control ( $wp_customize,'graduate_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'graduate-pro' ),
	'section'           => 'graduate_pro_slider_section',
	'type'              => 'dropdown-category',
	'active_callback'	=> 'graduate_pro_is_slider_category_content_active'
) ) );