<?php
/**
* Social Section options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Social Section enable section
$wp_customize->add_section( 'graduate_pro_social_section', array(
	'title'             => esc_html__( 'Social Section','graduate-pro' ),
	'description'		=> esc_html__( 'Social Section Options', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add Social Section enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[social_section_enable]', array(
	'default'           => $options['social_section_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[social_section_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_social_section',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add Social Section title
$wp_customize->add_setting( 'graduate_pro_theme_options[social_section_title]', array(
	'default'           => $options['social_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[social_section_title]', array(
	'label'             => esc_html__( 'Title', 'graduate-pro' ),
	'section'           => 'graduate_pro_social_section',
	'type'              => 'text',
	'active_callback'   => 'graduate_pro_is_social_section_active'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'graduate_pro_theme_options[social_section_title]', array(
		'selector'            => '#social-menu .entry-header h2.entry-title',
		'settings'            => 'graduate_pro_theme_options[social_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'graduate_pro_partial_social_section_title',
    ) );
}

// Add Social Section background image
$wp_customize->add_setting( 'graduate_pro_theme_options[social_section_image]',
	array(
	'sanitize_callback' 	=> 'graduate_pro_sanitize_image',
	)
);
$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'graduate_pro_theme_options[social_section_image]',
		array(
			'label'       		=> esc_html__( 'Select Background Image', 'graduate-pro' ),
			'description' 		=> sprintf( esc_html__( 'Note: You can replace default background. Recommended size: %1$dpx x %2$dpx ', 'graduate-pro' ), 1300, 300 ),
			'section'     		=> 'graduate_pro_social_section',
			'active_callback'	=> 'graduate_pro_is_social_section_active',
		)
	)
);

// Add Social Section enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[social_section_content_type]', array(
	'default'           => $options['social_section_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[social_section_content_type]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_social_section',
	'type'              => 'select',
	'choices'           => graduate_pro_social_content_type()
) );

// Add Social Section links count
$wp_customize->add_setting( 'graduate_pro_theme_options[social_section_count]', array(
	'default'           => $options['social_section_count'],
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback' => 'graduate_pro_validate_social_section_count'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[social_section_count]', array(
	'label'             => esc_html__( 'No. of Social Links', 'graduate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then referesh the page to see the change.', 'graduate-pro' ),
	'section'           => 'graduate_pro_social_section',
	'type'              => 'number',
	'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 10,
			'style'	=> 'width:100px'
		),
	'active_callback'   => 'graduate_pro_is_social_section_custom'
) );

for ( $i = 1; $i <= $options['social_section_count']; $i++ ) {

	// Add Social link hr setting and control
	$wp_customize->add_setting( 'graduate_pro_theme_options[social_link_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new graduate_Pro_Customize_Horizontal_Line( $wp_customize, 'graduate_pro_theme_options[social_link_hr_'. $i .']',
		array(
			'section'         => 'graduate_pro_social_section',
			'active_callback' => 'graduate_pro_is_social_section_custom',
			'type'			  => 'hr'
	) ) );

	// Add Social link title
	$wp_customize->add_setting( 'graduate_pro_theme_options[social_link_title_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[social_link_title_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Link Title %d', 'graduate-pro' ), $i ),
		'section'           => 'graduate_pro_social_section',
		'type'              => 'text',
		'active_callback'   => 'graduate_pro_is_social_section_custom'
	) );

	// Add Social link url
	$wp_customize->add_setting( 'graduate_pro_theme_options[social_link_url_'. $i .']', array(
		'sanitize_callback' => 'esc_url_raw'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[social_link_url_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Link Url %d', 'graduate-pro' ), $i ),
		'section'           => 'graduate_pro_social_section',
		'type'              => 'url',
		'active_callback'   => 'graduate_pro_is_social_section_custom'
	) );

}