<?php
/**
 * featured_content section
 *
 * This is the template for the content of featured_content section
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */
if ( ! function_exists( 'graduate_pro_add_featured_content_section' ) ) :
  /**
   * Add featured_content section
   *
   *@since Graduate Pro 1.0
   */
  function graduate_pro_add_featured_content_section() {

    // Check if featured_content is enabled on frontpage
    $featured_content_enable = apply_filters( 'graduate_pro_section_status', true, 'featured_content_enable' );
    if ( true !== $featured_content_enable ) {
      return false;
    }

    // Get featured_content section details
    $section_details = array();
    $section_details = apply_filters( 'graduate_pro_filter_featured_content_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render featured_content section now.
    graduate_pro_render_featured_content_section( $section_details );
  }
endif;
add_action( 'graduate_pro_primary_content', 'graduate_pro_add_featured_content_section', 90 );


if ( ! function_exists( 'graduate_pro_get_featured_content_section_details' ) ) :
  /**
   * featured_content section details.
   *
   * @since Graduate Pro 1.0
   * @param array $input featured_content section details.
   */
  function graduate_pro_get_featured_content_section_details( $input ) {
    $options = graduate_pro_get_theme_options();

    // featured_content type
    $featured_content_type  = $options['featured_content_type'];

    $content = array();
    switch ( $featured_content_type ) {
        case 'demo':
            $image      = array( 1 => 'campus-tours', 2 => 'country-guides' );
            $title      = array( 1 => esc_html__( 'Campus Tours', 'graduate-pro' ), 2 => esc_html__( 'Country Guides', 'graduate-pro' ) );
            $excerpt    = array( 1 => esc_html__( 'In euismod risus nec pellentesque egestas.', 'graduate-pro' ), 2 => esc_html__( 'All about vias, how to apply and things you should know.', 'graduate-pro' ) );
            for( $i = 1; $i <= 2; $i++ ) {
                $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/' . $image[$i] . '.jpg';
                $content[$i]['url']          = '#';
                $content[$i]['alt']          = esc_attr__( 'Featured Content Image', 'graduate-pro' );
                $content[$i]['title']        = $title[$i];
                $content[$i]['excerpt']      = $excerpt[$i];
            }
        break;

        case 'page':
            $ids = array();

            for ( $i = 1; $i <= 2; $i++ ) {
                $id = null;
                if ( isset( $options[ 'featured_content_page_'.$i ] ) ) {
                    $id = $options[ 'featured_content_page_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $args = array(
                'no_found_rows'  => true,
                'orderby'        => 'post__in',
                'post_type'      => 'page',
                'post__in'       => $ids,
            );
        break;

        case 'post':
            $ids = array();

            for ( $i = 1; $i <= 2; $i++ ) {
                $id = null;
                if ( isset( $options[ 'featured_content_post_'.$i ] ) ) {
                    $id = $options[ 'featured_content_post_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[] = absint( $id );
                }
            }

            // Bail if no valid posts are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $args = array(
                'no_found_rows'  => true,
                'orderby'        => 'post__in',
                'post_type'      => 'post',
                'post__in'       => $ids,
            );
        break;

        case 'category':
            $cat_id = '';
            if ( ! empty( $options['featured_content_category'] ) ) {
                $cat_id = $options['featured_content_category'];
            }

            // Bail if no valid pages are selected.
            if ( empty( $cat_id ) ) {
                return $input;
            }else{
                $cat_id = absint( $cat_id );
            }

            $args = array(
                'no_found_rows'  => true,
                'cat'            => $cat_id,
                'post_type'      => 'post',
                'posts_per_page' => 2,
            );
        break;


        case 'cat-list':
            $ids = array();

            for ( $i = 1; $i <= 2; $i++ ) {
                $id = null;
                if ( isset( $options[ 'featured_content_cat_list_'.$i ] ) ) {
                    $id = $options[ 'featured_content_cat_list_'.$i ];
                }
                if ( ! empty( $id ) ) {
                    $ids[$i] = absint( $id );
                }
            }

            // Bail if no valid pages are selected.
            if ( empty( $ids ) ) {
                return $input;
            }

            $i = 1;
            foreach ( $ids as $cat_list ) {
                $cat_id     = $ids[$i];
                $category   = get_category( $cat_id );

                $content[$i]['url']             = get_category_link( $cat_id );
                $content[$i]['title']           = $category->name;
                $content[$i]['excerpt']         = category_description( $cat_id );
                $content[$i]['alt']             = $category->name;
                $content[$i]['img_array'][0]    = ! empty( $options['featured_content_image_'. $i] ) ? $options['featured_content_image_'. $i] : get_template_directory_uri().'/assets/uploads/no-featured-image-600x200.jpg';
                $i++;
            }
        break;

        default:
        break;
    }

    if ( 'demo' != $featured_content_type && 'cat-list' != $featured_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
              $page_id = $post->ID;
              $img_array = null;
            if ( has_post_thumbnail( $page_id ) ) {
                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
            } else {
                $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-600x200.jpg';
            }

            if ( isset( $img_array ) ) {
              $content[$i]['img_array'] = $img_array;
            }

            $content[$i]['url']      = get_permalink( $page_id );
            $content[$i]['alt']      = get_the_title( $page_id );
            $content[$i]['title']    = get_the_title( $page_id );
            $content[$i]['excerpt']  = graduate_pro_trim_content( 7, $post  );

            $i++;
          }
          wp_reset_postdata();
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// featured_content section content details.
add_filter( 'graduate_pro_filter_featured_content_section_details', 'graduate_pro_get_featured_content_section_details' );


if ( ! function_exists( 'graduate_pro_render_featured_content_section' ) ) :
  /**
   * Start featured_content section
   *
   * @return string featured_content content
   * @since Graduate Pro 1.0
   *
   */
   function graduate_pro_render_featured_content_section( $content_details = array() ) {
        $options        = graduate_pro_get_theme_options();

        if ( empty( $content_details ) ) {
          return;
        } ?>

        <section id="category-blog" class="two-columns">
            <div class="container">
                <?php foreach( $content_details as $content_detail ) : ?>
                    <div class="column-wrapper wow fadeIn" data-wow-delay="0.1s" data-wow-duration="0.3s">
                        <div class="category-text wow fadeInUp" data-wow-delay="0.2s" data-wow-duration="0.3s" style="background-image:url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>');">
                            <div class="black-overlay"></div>
                            <h2><a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="color-white"><?php echo esc_html( $content_detail['title'] ); ?></a></h2>
                            <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                        </div><!--category-text-->
                    </div><!--.column-wrapper-->
                <?php endforeach; ?>
            </div><!--.container-->
        </section><!--#category-blog-->
<?php 
    }
endif;